clashroyale
===========

.. image:: https://img.shields.io/pypi/v/clashroyale.svg
   :alt: PyPi

.. image:: https://travis-ci.com/cgrok/clashroyale.svg?branch=master
    :target: https://travis-ci.com/cgrok/clashroyale

This library is currently an (a)sync wrapper for
https://royaleapi.com and the official Clash Royale API with
great functionality.

Installation
============

.. code-block:: python

    pip install clashroyale

Documentation
=============

Hosted on readthedocs.io `https://clashroyale.readthedocs.io
<https://clashroyale.readthedocs.io>`_.